<?php
/**
 * Most important functions used in other files
 */

if(!defined('ABSPATH')) {
	exit;
}

// Get data by ReST API
function xmpp_stats_restapi_data($command, $arguments = array()) {
	// POST arguments
	$args = array(
		'headers' => array(
			'Authorization' => 'Basic '.base64_encode(get_option('xmpp_stats_login').':'.get_option('xmpp_stats_password')),
			'X-Admin' => 'true'
		),
		'body' => json_encode($arguments),
		'redirection' => 0,
		'httpversion' => '1.1'
	);
	// POST data
	$rest_url = get_option('xmpp_stats_rest_url');
	$retry_count = 0;
	while($retry_count < 3) {
		$response = wp_remote_post($rest_url.'/'.$command, $args);
		if(is_wp_error($response)) { /* error */ }
		else if($response['response']['code'] == 200) {
			break;
		}
		$retry_count++;
	}
	// Server temporarily unavailable
	if(is_wp_error($response)) {
		return;
	}
	// Verify response
	else if($response['response']['code'] == 200) {
		// Return response body
		return $response['body'];
	}
	// Unexpected error
	return;
}

// Change seconds to friendly view
function xmpp_stats_seconds_to_datestamp($seconds) {
	if($seconds == 0) return '0s';
	$return = '';
    $can_print = false;
    $divs = array(86400, 3600, 60, 1);
    for($div=0; $div<4; $div++) {
        $res = (int)($seconds/$divs[$div]);
        $rem = $seconds % $divs[$div];
        if($res != 0) $can_print = true;
        if($can_print) $return .= sprintf('%d%s ', $res, substr('dhms', $div, 1));
        $seconds = $rem;
    }
    return trim($return);
}

// Caching Headers
function xmpp_stats_cache_header($seconds) {
	$ts = gmdate('d M Y H:i:s', time() + $seconds) . ' GMT';
	header("Expires: $ts");
	header('Pragma: cache');
	header("Cache-Control: max-age=$seconds");;
}
